@@ -77,7 +77,9 @@ NotificationManager::NotificationManager(QObject *parent)
     m_systemApps = config->value("systemApps").toStringList();
     // TODO temporary fix for AppNamesMap
     m_appNamesMap = config->value("AppNamesMap").toMap();
-
+    if(!config->value("notificationCleanupDays").isNull()) {
+        m_cleanupDays = config->value("notificationCleanupDays").toInt();
+    } 
     if (QStringLiteral("wayland") != QGuiApplication::platformName()) {
         initScreenLockedState();
     }
@@ -168,6 +170,15 @@ void NotificationManager::removeNotifications()
     emitRecordCountChanged();
 }
 
+void NotificationManager::removeExpiredNotifications()
+{
+    qDebug(notifyLog) << "Remove expired notifications.";
+    const qint64 cutoffTime = QDateTime::currentDateTime().addDays(-m_cleanupDays).toMSecsSinceEpoch();
+    m_persistence->removeEntitiesByExpiredTime(cutoffTime);
+
+    emitRecordCountChanged();
+}
+
 QStringList NotificationManager::GetCapabilities()
 {
     QStringList result;
@@ -212,7 +223,8 @@ uint NotificationManager::Notify(const QString &appName, uint replacesId, const
     }
 
     QString strBody = body;
-    strBody.replace(QLatin1String("\\\\"), QLatin1String("\\"), Qt::CaseInsensitive);
+    // Unescape backslashes and quotes from %q formatted strings (e.g., \\ -> \, \" -> ", \' -> ')
+    strBody.replace(QRegularExpression("\\\\(\\\\|['\"])"), "\\1");
 
     QString strIcon = appIcon;
     if (strIcon.isEmpty())
@@ -457,6 +469,8 @@ void NotificationManager::updateEntityProcessed(qint64 id, uint reason)
     if (entity.isValid()) {
         if ((reason == NotifyEntity::Closed || reason == NotifyEntity::Dismissed) && entity.processedType() == NotifyEntity::NotProcessed) {
             entity.setProcessedType(NotifyEntity::Removed);
+        } else if (reason == NotifyEntity::Timeout) {
+            entity.setProcessedType(NotifyEntity::Removed);
         } else {
             entity.setProcessedType(NotifyEntity::Processed);
         }
